util

package
v1.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2022 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func GetInputChannel added in v1.2.2

func GetInputChannel(ctx context.Context, uniqueIdentifiersInFile map[string]bool) (<-chan []byte, error)

GetInputChannel reads identifiers from a file to a channel

func GetInsights added in v1.2.2

func GetInsights(uniqueIdentifiersInFile map[string]bool) *v1.Insights

returns insights for the identifiers in the file

func GetUniqueIdentifiersInFile added in v1.2.2

func GetUniqueIdentifiersInFile(r io.Reader) (map[string]bool, error)

returns unique identifiers in the file

func ThresholdAndClampMatchResult added in v1.0.2

func ThresholdAndClampMatchResult(result *v1.ExternalMatchResult, srcInsight *v1.Insights)

ThresholdAndClampMatchResult modifies the received match result insight numbers by applying a threshold on the received value first, if the value is less than the threshold, it will be set to 0. Afterwards, we clamp the thresholded value.

Types

This section is empty.

Jump to