Documentation
¶
Index ¶
- func GetInputChannel(ctx context.Context, uniqueIdentifiersInFile map[string]bool) (<-chan []byte, error)
- func GetInsights(uniqueIdentifiersInFile map[string]bool) *v1.Insights
- func GetUniqueIdentifiersInFile(r io.Reader) (map[string]bool, error)
- func ThresholdAndClampMatchResult(result *v1.ExternalMatchResult, srcInsight *v1.Insights)
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetInputChannel ¶ added in v1.2.2
func GetInputChannel(ctx context.Context, uniqueIdentifiersInFile map[string]bool) (<-chan []byte, error)
GetInputChannel reads identifiers from a file to a channel
func GetInsights ¶ added in v1.2.2
returns insights for the identifiers in the file
func GetUniqueIdentifiersInFile ¶ added in v1.2.2
returns unique identifiers in the file
func ThresholdAndClampMatchResult ¶ added in v1.0.2
func ThresholdAndClampMatchResult(result *v1.ExternalMatchResult, srcInsight *v1.Insights)
ThresholdAndClampMatchResult modifies the received match result insight numbers by applying a threshold on the received value first, if the value is less than the threshold, it will be set to 0. Afterwards, we clamp the thresholded value.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.